@@ -8,6 +8,7 @@
 import logging
 from decimal import Decimal
 
+from pywps.inout.literaltypes import AnyValue, NoValue, ValuesReference
 from pywps.validator.mode import MODE
 from pywps.validator.allowed_value import ALLOWEDVALUETYPE, RANGECLOSURETYPE
 
@@ -15,6 +16,23 @@ from pywps.validator.allowed_value import ALLOWEDVALUETYPE, RANGECLOSURETYPE
 LOGGER = logging.getLogger('PYWPS')
 
 
+def validate_value(data_input, mode):
+    """Validate a literal value of type string, integer etc.
+
+    TODO: not fully implemented
+    """
+    if mode == MODE.NONE:
+        passed = True
+    else:
+        LOGGER.debug('validating literal value.')
+        data_input.data
+        # TODO: we currently rely only on the data conversion in `pywps.inout.literaltypes.convert`
+        passed = True
+
+    LOGGER.debug('validation result: {}'.format(passed))
+    return passed
+
+
 def validate_anyvalue(data_input, mode):
     """Just placeholder, anyvalue is always valid
     """
@@ -22,6 +40,23 @@ def validate_anyvalue(data_input, mode):
     return True
 
 
+def validate_values_reference(data_input, mode):
+    """Validate values reference
+
+    TODO: not fully implemented
+    """
+    if mode == MODE.NONE:
+        passed = True
+    else:
+        LOGGER.debug('validating values reference.')
+        data_input.data
+        # TODO: we don't validate if the data is within the reference values
+        passed = True
+
+    LOGGER.debug('validation result: {}'.format(passed))
+    return passed
+
+
 def validate_allowed_values(data_input, mode):
     """Validate allowed values
     """
@@ -32,10 +67,15 @@ def validate_allowed_values(data_input, mode):
     else:
         data = data_input.data
 
-        LOGGER.debug('validating allowed values: %s in %s', data, data_input.allowed_values)
+        LOGGER.debug('validating allowed values: {} in {}'.format(data, data_input.allowed_values))
         for value in data_input.allowed_values:
 
-            if value.allowed_type == ALLOWEDVALUETYPE.VALUE:
+            if isinstance(value, (AnyValue, NoValue, ValuesReference)):
+                # AnyValue, NoValue and ValuesReference always pass validation
+                # NoValue and ValuesReference are not implemented
+                passed = True
+
+            elif value.allowed_type == ALLOWEDVALUETYPE.VALUE:
                 passed = _validate_value(value, data)
 
             elif value.allowed_type == ALLOWEDVALUETYPE.RANGE:
@@ -44,7 +84,7 @@ def validate_allowed_values(data_input, mode):
             if passed is True:
                 break
 
-    LOGGER.debug('validation result: %r', passed)
+    LOGGER.debug('validation result: {}'.format(passed))
     return passed
 
 
@@ -68,7 +108,7 @@ def _validate_range(interval, data):
 
     passed = False
 
-    LOGGER.debug('validating range: %s in %r', data, interval)
+    LOGGER.debug('validating range: {} in {}'.format(data, interval))
     if interval.minval <= data <= interval.maxval:
 
         if interval.spacing:
@@ -80,15 +120,15 @@ def _validate_range(interval, data):
 
         if passed:
             if interval.range_closure == RANGECLOSURETYPE.OPEN:
-                passed = (interval.minval <= data <= interval.maxval)
-            elif interval.range_closure == RANGECLOSURETYPE.CLOSED:
                 passed = (interval.minval < data < interval.maxval)
+            elif interval.range_closure == RANGECLOSURETYPE.CLOSED:
+                passed = (interval.minval <= data <= interval.maxval)
             elif interval.range_closure == RANGECLOSURETYPE.OPENCLOSED:
-                passed = (interval.minval <= data < interval.maxval)
-            elif interval.range_closure == RANGECLOSURETYPE.CLOSEDOPEN:
                 passed = (interval.minval < data <= interval.maxval)
+            elif interval.range_closure == RANGECLOSURETYPE.CLOSEDOPEN:
+                passed = (interval.minval <= data < interval.maxval)
     else:
         passed = False
 
-    LOGGER.debug('validation result: %r', passed)
+    LOGGER.debug('validation result: {}'.format(passed))
     return passed
