@@ -288,9 +288,10 @@ class SerializationComplexInputTest(unittest.TestCase):
     def test_complex_input_data(self):
         complex = self.make_complex_input()
         complex.data = "some data"
+        # the data is enclosed by a CDATA tag in json
+        assert complex.json['data'] == '<![CDATA[some data]]>'
+        # dump to json and load it again
         complex2 = inout.inputs.ComplexInput.from_json(complex.json)
-        # the data is enclosed by a CDATA tag
-        complex._data = u'<![CDATA[{}]]>'.format(complex.data)
         # it's expected that the file path changed
         complex._file = complex2.file
 
@@ -299,14 +300,14 @@ class SerializationComplexInputTest(unittest.TestCase):
 
     def test_complex_input_stream(self):
         complex = self.make_complex_input()
-        complex.stream = StringIO("some data")
+        complex.stream = StringIO("{'name': 'test', 'input1': ']]'}")
+        # the data is enclosed by a CDATA tag in json
+        assert complex.json['data'] == "<![CDATA[{'name': 'test', 'input1': ']]'}]]>"
+        # dump to json and load it again
         complex2 = inout.inputs.ComplexInput.from_json(complex.json)
-
         # the serialized stream becomes a data type
         # we hard-code it for the testing comparison
         complex.prop = 'data'
-        # the data is enclosed by a CDATA tag
-        complex._data = u'<![CDATA[{}]]>'.format(complex.data)
         # it's expected that the file path changed
         complex._file = complex2.file
 
@@ -381,18 +382,18 @@ class SerializationBoundingBoxInputTest(unittest.TestCase):
 
     def make_bbox_input(self):
         bbox = inout.inputs.BoundingBoxInput(
-            identifier="complexinput",
-            title='MyComplex',
+            identifier="bbox",
+            title='BBox',
             crss=['epsg:3857', 'epsg:4326'],
             abstract="some description",
             keywords=['kw1', 'kw2'],
             dimensions=2,
             workdir=self.tmp_dir,
-            metadata=[Metadata("special data")],
+            metadata=[Metadata("bbox")],
             min_occurs=2,
             max_occurs=5,
             mode=MODE.NONE,
-            default="something else",
+            default="0,50,20,70",
             default_type=SOURCE_TYPE.DATA,
         )
         bbox.as_reference = False
@@ -411,7 +412,6 @@ class SerializationBoundingBoxInputTest(unittest.TestCase):
         self.assertEqual(bbox_1.max_occurs, bbox_2.max_occurs)
         self.assertEqual(bbox_1.valid_mode, bbox_2.valid_mode)
         self.assertEqual(bbox_1.as_reference, bbox_2.as_reference)
-
         self.assertEqual(bbox_1.ll, bbox_2.ll)
         self.assertEqual(bbox_1.ur, bbox_2.ur)
 
@@ -683,8 +683,8 @@ class LiteralOutputTest(unittest.TestCase):
     def setUp(self):
 
         self.literal_output = inout.outputs.LiteralOutput(
-            "literaloutput", 
-            data_type="integer", 
+            "literaloutput",
+            data_type="integer",
             title="Literal Output",
             translations={"fr-CA": {"title": "Mon output", "abstract": "Une description"}},
         )
@@ -715,8 +715,8 @@ class BBoxInputTest(unittest.TestCase):
     def setUp(self):
 
         self.bbox_input = inout.inputs.BoundingBoxInput(
-            "bboxinput", 
-            title="BBox input", 
+            "bboxinput",
+            title="BBox input",
             dimensions=2,
             translations={"fr-CA": {"title": "Mon input", "abstract": "Une description"}},
         )
