@@ -16,13 +16,15 @@ from pywps.dependencies import ogr
 from pywps.exceptions import NoApplicableCode
 from pywps import get_ElementMakerForVersion
 from pywps.wpsserver import temp_dir
-from pywps.tests import client_for, assert_response_success
+import pywps.configuration as config
+from pywps.tests import client_for, assert_response_success, service_ok
 
-wfsResource = 'http://demo.mapserver.org/cgi-bin/wfs?service=WFS&version=1.1.0&request=GetFeature&typename=continents&maxfeatures=10'  # noqa
-wcsResource = 'http://demo.mapserver.org/cgi-bin/wcs?service=WCS&version=1.0.0&request=GetCoverage&coverage=ndvi&crs=EPSG:4326&bbox=-92,42,-85,45&format=image/tiff&width=400&height=300'  # noqa
+wfsResource = 'https://demo.mapserver.org/cgi-bin/wfs?service=WFS&version=1.1.0&request=GetFeature&typename=continents&maxfeatures=10'  # noqa
+wcsResource = 'https://demo.mapserver.org/cgi-bin/wcs?service=WCS&version=1.0.0&request=GetCoverage&coverage=ndvi&crs=EPSG:4326&bbox=-92,42,-85,45&format=image/tiff&width=400&height=300'  # noqa
 
 WPS, OWS = get_ElementMakerForVersion("1.0.0")
 
+
 def create_feature():
 
     def feature(request, response):
@@ -34,7 +36,7 @@ def create_feature():
         try:
             inSource = ogr.Open(input)
         except Exception as e:
-            return "Could not open given vector file: %s" % e
+            return "Could not open given vector file: {}".format(e)
         inLayer = inSource.GetLayer()
 
         # create output file
@@ -42,7 +44,9 @@ def create_feature():
         outPath = os.path.join(tempfile.gettempdir(), out)
 
         driver = ogr.GetDriverByName('GML')
-        outSource = driver.CreateDataSource(outPath, ["XSISCHEMAURI=http://schemas.opengis.net/gml/2.1.2/feature.xsd"])
+        outSource = driver.CreateDataSource(
+            outPath,
+            ["XSISCHEMAURI=http://schemas.opengis.net/gml/2.1.2/feature.xsd"])
         outLayer = outSource.CreateLayer(out, None, ogr.wkbUnknown)
 
         # get the first feature
@@ -65,49 +69,69 @@ def create_feature():
     return Process(handler=feature,
                    identifier='feature',
                    title='Process Feature',
-                   inputs=[ComplexInput('input', 'Input', supported_formats=[get_format('GML')])],
-                   outputs=[ComplexOutput('output', 'Output', supported_formats=[get_format('GML')])])
+                   inputs=[ComplexInput(
+                       'input',
+                       title='Input',
+                       supported_formats=[get_format('GML')])],
+                   outputs=[ComplexOutput(
+                       'output',
+                       title='Output',
+                       supported_formats=[get_format('GML')])])
 
 
 def create_sum_one():
 
     def sum_one(request, response):
-        input = request.inputs['input']
+        input = request.inputs['input'][0].file
         # What do we need to assert a Complex input?
         # assert type(input) is text_type
 
-        sys.path.append("/usr/lib/grass64/etc/python/")
         import grass.script as grass
 
         # Import the raster and set the region
-        if grass.run_command("r.in.gdal", flags="o", out="input", input=input) != 0:
-            raise NoApplicableCode("Could not import cost map. Please check the WCS service.")
+        if grass.run_command("r.in.gdal", flags="o", out="input",
+                             input=input, quiet=True) != 0:
+            raise NoApplicableCode("Could not import cost map. "
+                                   "Please check the WCS service.")
 
-        if grass.run_command("g.region", flags="ap", rast="input") != 0:
+        if grass.run_command("g.region", flags="a", rast="input") != 0:
             raise NoApplicableCode("Could not set GRASS region.")
 
         # Add 1
-        if grass.mapcalc("$output = $input + $value", output="output", input="input", value=1.0) != 0:
-            raise NoApplicableCode("Could not set GRASS region.")
+        if grass.mapcalc("$output = $input + $value", output="output",
+                         input="input", value=1.0, quiet=True):
+            raise NoApplicableCode("Could not use GRASS map calculator.")
 
         # Export the result
-        out = "./output.tif"
-        if grass.run_command("r.out.gdal", input="output", type="Float32", output=out) != 0:
+        _, out = tempfile.mkstemp()
+        os.environ['GRASS_VERBOSE'] = '-1'
+        if grass.run_command("r.out.gdal", flags="f", input="output",
+                             type="UInt16", output=out, overwrite=True) != 0:
             raise NoApplicableCode("Could not export result from GRASS.")
+        del os.environ['GRASS_VERBOSE']
 
-        response.outputs['output'] = out
+        response.outputs['output'].file = out
         return response
 
     return Process(handler=sum_one,
                    identifier='sum_one',
                    title='Process Sum One',
-                   inputs=[ComplexInput('input', [Format('image/img')])],
-                   outputs=[ComplexOutput('output', [Format('image/tiff')])])
+                   inputs=[ComplexInput(
+                       'input',
+                       title='Input',
+                       supported_formats=[Format('image/img')])],
+                   outputs=[ComplexOutput(
+                       'output',
+                       title='Output',
+                       supported_formats=[get_format('GEOTIFF')])],
+                   grass_location='epsg:4326')
 
 
 class ExecuteTests(unittest.TestCase):
 
     def test_wfs(self):
+        if not service_ok('https://demo.mapserver.org'):
+            self.skipTest("mapserver is unreachable")
         client = client_for(Service(processes=[create_feature()]))
         request_doc = WPS.Execute(
             OWS.Identifier('feature'),
@@ -132,18 +156,19 @@ class ExecuteTests(unittest.TestCase):
         # . the type of output
 
     def test_wcs(self):
-        try:
-            sys.path.append("/usr/lib/grass64/etc/python/")
-            import grass.script as grass
-        except Exception:
+        if not config.CONFIG.get('grass', 'gisbase'):
             self.skipTest('GRASS lib not found')
+        if not service_ok('https://demo.mapserver.org'):
+            self.skipTest("mapserver is unreachable")
+
         client = client_for(Service(processes=[create_sum_one()]))
         request_doc = WPS.Execute(
             OWS.Identifier('sum_one'),
             WPS.DataInputs(
                 WPS.Input(
                     OWS.Identifier('input'),
-                    WPS.Reference(href=wcsResource, mimeType='image/tiff'))),
+                    WPS.Reference(
+                        {'{http://www.w3.org/1999/xlink}href': wcsResource}))),
             WPS.ProcessOutputs(
                 WPS.Output(
                     OWS.Identifier('output'))),
